@@ -1,6 +1,7 @@
 #!/bin/sh -e
 # check if debmake works as expected
-LC_ALL=en_US.UTF-8
+# debmake project-ver/ for native
+LC_ALL=C.UTF-8
 export LC_ALL
 
 # native
@@ -10,7 +11,7 @@ rm -rf ${PROJECT}
 mkdir ${PROJECT}
 echo "DUMMY ${PROJECT}" > ${PROJECT}/dummy-${PROJECT}
 cd ${PROJECT} || exit 1
-debmake -n 2>&1
+debmake -n -x0
 test -x debian/rules
 cd .. || exit 1
 
